.. JAX-in-Cell documentation master file, created by
   sphinx-quickstart on Mon Feb 10 13:43:11 2025.
   You can adapt this file completely to your liking, but it should at least
   contain the root `toctree` directive.

.. image:: JAX-in-Cell_logo.png
   :width: 200px
   :align: center
   :target: https://github.com/uwplasma/JAX-in-Cell

.. image:: https://img.shields.io/badge/GitHub-Repository-blue
   :target: https://github.com/uwplasma/JAX-in-Cell
   :alt: GitHub repository
   :width: 100px
   :align: center

-------------------------

JAX-in-Cell Documentation
=========================

Welcome to **JAX-in-Cell**, an open-source JAX-based Particle-in-Cell (PIC) framework
for simulating plasmas with GPU/TPU acceleration, autodifferentiation, and JIT compilation.

.. toctree::
   :maxdepth: 2
   :caption: Contents:

   overview
   features
   project_structure
   getting_started
   usage
   testing
   roadmap
   contributing
   license
   acknowledgments